/***************************************************************************
              f4lmdoc.cpp  -  description
                 -------------------
    begin                : Sat Jun  7 02:29:46 EEST 2003
    copyright            : (C) 2003 by zkan pakdil
    email                : ozkanpakdil@users.sourceforge.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

// include files for Qt
#include <qdir.h>
#include <qfileinfo.h>
#include <qwidget.h>
#include <qmsgbox.h>
#include <qfiledialog.h>


// application specific includes
#include "f4lmdoc.h"
#include "f4lm.h"
#include "f4lmview.h"

F4lmDoc::F4lmDoc () {
    setName ("F4lmDoc");
    pViewList = new QList < F4lmView >;
    pLayerList = new QPtrList < CLayer >;
    pViewList->setAutoDelete (false);
}

F4lmDoc::~F4lmDoc () {
    delete pViewList;
}

void F4lmDoc::addView (F4lmView * view) {
    pViewList->append (view);
    changedViewList ();
}

void F4lmDoc::removeView (F4lmView * view) {
    pViewList->remove
    (view);
    if (!pViewList->isEmpty ())
    changedViewList ();
    else
    deleteContents ();
}

void F4lmDoc::changedViewList () {
    F4lmView *w;
    if ((int) pViewList->count () == 1) {
    w = pViewList->first ();
    w->setCaption (m_title);
    } else {
    int i;
    for (i = 1, w = pViewList->first (); w != 0;
        i++, w = pViewList->next ())
        w->setCaption (QString (m_title + ":%1").arg (i));
    }
}

bool F4lmDoc::isLastView () {
    return ((int) pViewList->count () == 1);
}

void F4lmDoc::updateAllViews (F4lmView * sender) {
    F4lmView *w;
    for (w = pViewList->first (); w != 0; w = pViewList->next ()) {
    w->update (sender);
    }
}

void F4lmDoc::setPathName (const QString & name) {
    m_filename = name;
    m_title = QFileInfo (name).fileName ();
}

const QString & F4lmDoc::pathName () const {
    return m_filename;
}

void F4lmDoc::setTitle (const QString & title) {
    m_title = title;
}

const QString & F4lmDoc::title () const {
    return m_title;
}

void F4lmDoc::closeDocument () {
    F4lmView *w;
    if (!isLastView ()) {
    for (w = pViewList->first (); w != 0; w = pViewList->next ()) {
        if (!w->close ())
        break;
    }
    }
    if (isLastView ()) {
    w = pViewList->first ();
    w->close ();
    }
}

bool F4lmDoc::newDocument () {
    /////////////////////////////////////////////////
    // TODO: Add your document initialization code here
    /////////////////////////////////////////////////
    modified = false;
    return true;
}

bool F4lmDoc::openDocument (const QString & filename, const char *format /*=0*/ ) {
    QFile f (filename);
    if (!f.open (IO_ReadOnly))
    return false;
    /////////////////////////////////////////////////
    // TODO: Add your document opening code here
    /////////////////////////////////////////////////
    f.close ();
    modified = false;
    m_filename = filename;
    m_title = QFileInfo (f).fileName ();
    return true;
}

bool F4lmDoc::saveDocument (const QString & filename, const char *format /*=0*/ ) {
    F4lmView* tmp= (F4lmView* )pViewList->at(0);
	canview *viving=tmp->canvasViewer;
	
	/*QCanvasItemList l = canvas ()->allItems ();
				for (QCanvasItemList::Iterator it = l.begin (); it != l.end (); ++it) {
						if ((*it)->rtti () == 667) {
    (*it)->hide ();
    delete *it;
						}
						mulSelect.clear ();
						mulSelectedRects.clear ();
				}*/
	
	QFile f (filename);
    if (!f.open (IO_WriteOnly))
    return false;

    /////////////////////////////////////////////////
    // TODO: Add your document saving code here
    /////////////////////////////////////////////////

    f.close ();

    modified = false;
    m_filename = filename;
    m_title = QFileInfo (f).fileName ();
    return true;
}

void F4lmDoc::deleteContents () {
    /////////////////////////////////////////////////
    // TODO: Add implementation to delete the document contents
    /////////////////////////////////////////////////

}

bool F4lmDoc::canCloseFrame (F4lmView * pFrame) {
    if (!isLastView ())
    return true;

    bool ret = false;
    if (isModified ()) {
    QString saveName;
    switch (QMessageBox::
        information (pFrame, title (),
                 tr ("The current file has been modified.\n"
                 "Do you want to save it?"), QMessageBox::Yes,
                 QMessageBox::No, QMessageBox::Cancel)) {
    case QMessageBox::Yes:
        if (title ().contains (tr ("Untitled"))) {
        saveName = QFileDialog::getSaveFileName (0, 0, pFrame);
        if (saveName.isEmpty ())
            return false;
        } else
        saveName = pathName ();

        if (!saveDocument (saveName)) {
        switch (QMessageBox::
            critical (pFrame, tr ("I/O Error !"),
                  tr ("Could not save the current document !\n"
                      "Close anyway ?"), QMessageBox::Yes,
                  QMessageBox::No)) {
        case QMessageBox::Yes:
            ret = true;
        case QMessageBox::No:
            ret = false;
        }
        } else
        ret = true;
        break;
    case QMessageBox::No:
        ret = true;
        break;
    case QMessageBox::Cancel:
    default:
        ret = false;
        break;
    }
    } else
    ret = true;

    return ret;
}
